@@ -12,7 +12,10 @@ maybe_update_logger_class()
 LOGGER_PREFIX = os.getenv("PYLAV__LOGGER_PREFIX")
 
 logging.getLogger("deepdiff.diff").setLevel(logging.FATAL)
-logging.getLogger("apscheduler.scheduler").setLevel(logging.FATAL)
+logging.getLogger("apscheduler").setLevel(logging.ERROR)
+logging.getLogger("aiohttp_client_cache").setLevel(logging.ERROR)
+logging.getLogger("aiocache").setLevel(logging.ERROR)
+
 
 if LOGGER_PREFIX is None:
     try:
